@@ -1,19 +1,21 @@
 #!/usr/bin/env python
-import os
-import tempfile
 import json
+import os
+import socketserver
 import sys
+import tempfile
+from http.server import SimpleHTTPRequestHandler
+
 import click
 from cookiecutter.main import cookiecutter
 
-from .config import SAVED_CONFIG_PATH, CONFIG_FILE_NAME, environment
-from .auth import ArchimedesAuth, AUTH_ACTIONS_LOGOUT, AUTH_ACTIONS_LOGIN, AUTH_ACTIONS_GET_TOKEN, AUTH_ACTIONS
 from . import __version__
-
-from http.server import SimpleHTTPRequestHandler
-import socketserver
+from .auth import (AUTH_ACTIONS, AUTH_ACTIONS_GET_TOKEN, AUTH_ACTIONS_LOGIN,
+                   AUTH_ACTIONS_LOGOUT, ArchimedesAuth)
+from .config import CONFIG_FILE_NAME, SAVED_CONFIG_PATH, environment
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+COOKIECUTTER_TEMPLATE_GIT_URL = "https://github.com/OptimeeringAS/archimedes-cookiecutter.git"
 
 
 class ConfigNotFoundException(Exception):
@@ -111,7 +113,15 @@ def auth(action, organization):
 #     help="Add this flag to include example files",
 # )
 # def new(name, examples):
-def new(name):
+@click.option(
+    "--template-version",
+    "-t",
+    "template_version",
+    help=f"Version of the template to use. It can be a branch, name or tag of the git repo of"
+         f"{COOKIECUTTER_TEMPLATE_GIT_URL}",
+    default=None,
+)
+def new(name, template_version):
     """"""
     # if examples == True:
     #     examples_ = "yes"
@@ -120,7 +130,8 @@ def new(name):
 
     try:
         project_dir = cookiecutter(
-            "https://git.optimeering.no/archimedes/archimedes-cookiecutter.git",
+            COOKIECUTTER_TEMPLATE_GIT_URL,
+            checkout=template_version,
             extra_context=get_config(name),
             no_input=True,
         )
@@ -140,7 +151,7 @@ def new(name):
     click.echo(f"to view more information.")
     click.echo("")
     click.echo(f'$ cd "{project_dir}"')
-    click.echo(f"$ python -m pip install poetry wheel pip --upgrade")
+    click.echo(f"$ python -m pip install wheel pip --upgrade")
     click.echo(f"$ poetry update --lock")
     click.echo(f"$ poetry install")
     click.echo("")
@@ -149,7 +160,15 @@ def new(name):
 
 
 @cli.command(hidden=True)
-def init():
+@click.option(
+    "--template-version",
+    "-t",
+    "template_version",
+    help=f"Version of the template to use. It can be a branch, name or tag of the git repo of"
+         f"{COOKIECUTTER_TEMPLATE_GIT_URL}",
+    default=None,
+)
+def init(template_version):
     """
     Initialize Archimedes in an existing directory
     """
@@ -169,7 +188,8 @@ def init():
     # Create a temporary project from cookiecutter and copy archimedes.toml from it to the current project directory
     with tempfile.TemporaryDirectory(dir=".") as tmp_dir_name:
         temporary_project_directory = cookiecutter(
-            "https://git.optimeering.no/archimedes/archimedes-cookiecutter.git",
+            COOKIECUTTER_TEMPLATE_GIT_URL,
+            checkout=template_version,
             extra_context=config,
             no_input=True,
             output_dir=tmp_dir_name,
@@ -179,7 +199,7 @@ def init():
             os.path.join(project_directory, CONFIG_FILE_NAME),
         )
 
-    click.echo(f"The project `{project_name}`` was initialized!")
+    click.echo(f"The project `{project_name}` was initialized!")
 
 
 @cli.command(hidden=True)
